
from tastypie.serializers import Serializer as DefaultSerializer
import msgpack


class Serializer(DefaultSerializer):

    def __init__(self, *args, **kwargs):
        super(Serializer, self).__init__(*args, **kwargs)
        self.formats.append("msgpack")
        self.content_types["msgpack"] = "application/x-msgpack"

    def to_msgpack(self, data, options=None):
        return msgpack.packb(self.to_simple(data, options or {}))

    def from_msgpack(self, content):
        return msgpack.unpackb(content)




from setuptools import setup, find_packages


setup(
    name="tastypie-msgpack",
    version="0.0.3",
    author="Stephen McDonald",
    author_email="stephen.mc@gmail.com",
    description="MsgPack support for Django Tastypie.",
    long_description=open("README.rst").read(),
    license="BSD",
    url="https://github.com/stephenmcd/tastypie-msgpack",
    install_requires=["msgpack-python"],
    packages=['tastypie_msgpack'],
    classifiers=[
        "Development Status :: 4 - Beta",
        "Environment :: Web Environment",
        "Framework :: Django",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: BSD License",
        "Operating System :: OS Independent",
        "Programming Language :: Python",
        "Topic :: Internet :: WWW/HTTP",
        "Topic :: Software Development :: Libraries :: Python Modules",
    ]
)
